<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:bp1="http://www.ebxml.org/BusinessProcess/1.01" version="1.0">
    <xsl:key name="bt" match="//bp1:BusinessTransaction" use="@nameID"/>
    <!--  
    1. Add conditionals for optional elements and  attributes
    2.  Add iterations for repeatable elements as needed.
    3. Missing required elements and attributes inserted with empty text nodes.
    4. Checks on semantics, warnings of incomplete elements, etc.
    -->
    <xsl:template match="/">
        <xsl:element name="ProcessSpecification" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="bp1:ProcessSpecification/@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="bp1:ProcessSpecification/@nameID"/>
            </xsl:attribute>
            <xsl:attribute name="specificationVersion">2.0</xsl:attribute>
            <xsl:attribute name="instanceVersion">instance.<xsl:value-of select="bp1:ProcessSpecification/@uuid"/>
            </xsl:attribute>
            <xsl:attribute name="uuid">
                <xsl:value-of select="bp1:ProcessSpecification/@uuid"/>
            </xsl:attribute>
            <xsl:apply-templates select="//bp1:ProcessSpecification/bp1:Documentation"/>
            <!-- AttributeSubstitution  -->
            <!-- ExternalRoles -->
            <!-- Signal   -->
            <!-- Variable  -->
            <!-- Choice over the components of the content. Original document order is not preserved.-->
            <xsl:apply-templates select="bp1:ProcessSpecification/bp1:Package"/>
            <xsl:apply-templates select="bp1:ProcessSpecification/bp1:BusinessDocument"/>
            <xsl:apply-templates select="bp1:ProcessSpecification/bp1:BusinessTransaction"/>
            <xsl:apply-templates select="bp1:ProcessSpecification/bp1:BinaryCollaboration"/>
            <xsl:apply-templates select="bp1:ProcessSpecification/bp1:MultiPartyCollaboration"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:Documentation">
        <xsl:element name="Documentation" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:value-of select="."/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:BusinessDocument">
        <xsl:element name="BusinessDocument" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <xsl:apply-templates select="bp1:ConditionExpression"/>
            <!--   ConditionExpression -->
            <!--   Specification   -->
            <xsl:element name="Specification" namespace="http://www.oasis-open.org/committes/ebBP">
                <xsl:attribute name="name">
                    <xsl:value-of select="./@name"/>
                </xsl:attribute>
                <xsl:attribute name="nameID">
                    <xsl:value-of select="./@nameID"/>
                </xsl:attribute>
                <xsl:if test="./@type">
                    <xsl:attribute name="type">
                        <xsl:value-of select="./@type"/>
                    </xsl:attribute>
                </xsl:if>
                <xsl:if test="./@targetNamespace">
                    <xsl:attribute name="targetNamespace">
                        <xsl:value-of select="./@retryCount"/>
                    </xsl:attribute>
                </xsl:if>
                <xsl:if test="./@specificationLocation">
                    <xsl:attribute name="location">
                        <xsl:value-of select="./@specificationLocation"/>
                    </xsl:attribute>
                </xsl:if>
            </xsl:element>
            <!--xsl:apply-templates select="bp1:Documentation"/-->
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:BusinessTransaction">
        <xsl:element name="BusinessTransaction" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:RequestingBusinessActivity"/>
            <xsl:apply-templates select="bp1:RespondingBusinessActivity"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:RequestingBusinessActivity">
        <xsl:element name="RequestingBusinessActivity" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:if test="./@isAuthorizationRequired">
                <xsl:attribute name="isAuthorizationRequired">
                    <xsl:value-of select="./@isAuthorizationRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@isIntelligibleCheckRequired">
                <xsl:attribute name="isIntelligibleCheckRequired">
                    <xsl:value-of select="./@sIntelligibleCheckRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@isNonRepudiationReceiptRequired">
                <xsl:attribute name="isNonRepudiationReceiptRequired">
                    <xsl:value-of select="./@isNonRepudiationReceiptRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@isNonRepudiationRequired">
                <xsl:attribute name="isNonRepudiationRequired">
                    <xsl:value-of select="./@isNonRepudiationRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@timeToAcknowledgeReceipt">
                <xsl:attribute name="timeToAcknowledgeReceipt">
                    <xsl:value-of select="./@timeToAcknowledgeReceipt"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@retryCount">
                <xsl:attribute name="retryCount">
                    <xsl:value-of select="./@retryCount"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="bp1:DocumentEnvelope"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:RespondingBusinessActivity">
        <xsl:element name="RespondingBusinessActivity" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:if test="./@isAuthorizationRequired">
                <xsl:attribute name="isAuthorizationRequired">
                    <xsl:value-of select="./@isAuthorizationRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@isIntelligibleCheckRequired">
                <xsl:attribute name="isIntelligibleCheckRequired">
                    <xsl:value-of select="./@isIntelligibleCheckRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@isNonRepudiationReceiptRequired">
                <xsl:attribute name="isNonRepudiationReceiptRequired">
                    <xsl:value-of select="./@isNonRepudiationReceiptRequired"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@isNonRepudiationRequired">
                <xsl:attribute name="isNonRepudiationRequired">
                    <xsl:value-of select="./@isNonRepudiationRequiredD"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@timeToAcknowledgeReceipt">
                <xsl:attribute name="timeToAcknowledgeReceipt">
                    <xsl:value-of select="./@timeToAcknowledgeReceipt"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="./@retryCount">
                <xsl:attribute name="retryCount">
                    <xsl:value-of select="./@retryCount"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="bp1:DocumentEnvelope"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:DocumentEnvelope">
        <xsl:element name="DocumentEnvelope" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:if test="@isPositiveResponse">
                <xsl:attribute name="isPositiveResponse">
                    <xsl:value-of select="@isPositiveResponse"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@businessDocumentIDREF">
                <xsl:attribute name="businessDocumentRef">
                    <xsl:value-of select="@businessDocumentIDREF"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@isAuthenticated">
                <xsl:attribute name="isAuthenticated">
                    <xsl:value-of select="@isAuthenticated"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@isConfidential">
                <xsl:attribute name="isConfidential">
                    <xsl:value-of select="@isConfidential"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@isTamperDetectable">
                <xsl:attribute name="isTamperDetectable">
                    <xsl:value-of select="@isTamperDetectable"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="bp1:Documentation"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:Package">
        <xsl:element name="Package" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:BusinessDocument"/>
            <xsl:apply-templates select="bp1:BusinessTransaction"/>
            <xsl:apply-templates select="bp1:BinaryCollaboration"/>
            <xsl:apply-templates select="bp1:Package"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:BinaryCollaboration">
        <xsl:element name="BinaryCollaboration" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:attribute name="pattern">
                <xsl:value-of select="./@pattern"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <xsl:apply-templates select="bp1:Role"/>
            <xsl:apply-templates select="bp1:BusinessTransactionActivity"/>
            <xsl:apply-templates select="bp1:CollaborationActivity"/>
            <xsl:apply-templates select="bp1:Transition"/>
            <xsl:apply-templates select="bp1:Success"/>
            <xsl:apply-templates select="bp1:Failure"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:Role">
        <xsl:element name="Role" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:CollaborationActivity">
        <xsl:element name="CollaborationActivity" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:BusinessTransactionActivity">
        <xsl:element name="BusinessTransactionActivity" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:attribute name="businessTransactionRef">
                <xsl:value-of select="./@businessTransactionIDREF"/>
            </xsl:attribute>
            <xsl:attribute name="hasLegalIntent">
                <xsl:value-of select="./@isLegallyBinding"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <xsl:if test="../@beginsWhen">
                <xsl:element name="BeginsWhen" namespace="http://www.oasis-open.org/committes/ebBP">
                    <xsl:attribute name="expression">
                        <xsl:value-of select="../@beginsWhen"/>
                    </xsl:attribute>
                    <xsl:attribute name="expressionLanguage">
                        <xsl:value-of select="'DocumentEnvelope'"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
            <xsl:if test="../@endsWhen">
                <xsl:element name="EndsWhen" namespace="http://www.oasis-open.org/committes/ebBP">
                    <xsl:attribute name="expression">
                        <xsl:value-of select="../@iendsWhen"/>
                    </xsl:attribute>
                    <xsl:attribute name="expressionLanguage">
                        <xsl:value-of select="'DocumentEnvelope'"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
            <xsl:if test="../@preCondition">
                <xsl:element name="PreCondition" namespace="http://www.oasis-open.org/committes/ebBP">
                    <xsl:attribute name="expression">
                        <xsl:value-of select="../@preCondition"/>
                    </xsl:attribute>
                    <xsl:attribute name="expressionLanguage">
                        <xsl:value-of select="'DocumentEnvelope'"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
            <xsl:if test="../@postCondition">
                <xsl:element name="PostCondition" namespace="http://www.oasis-open.org/committes/ebBP">
                    <xsl:attribute name="expression">
                        <xsl:value-of select="../@postCondition"/>
                    </xsl:attribute>
                    <xsl:attribute name="expressionLanguage">
                        <xsl:value-of select="'DocumentEnvelope'"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
            <xsl:variable name="ref" select="./@businessTransactionIDREF"/>
            <xsl:element name="Performs" namespace="http://www.oasis-open.org/committes/ebBP">
                <xsl:attribute name="currentRoleRef">
                    <xsl:value-of select="./@fromRoleIDREF"/>
                </xsl:attribute>
                <xsl:attribute name="initiatingRoleRef">
                    <xsl:value-of select="key('bt',$ref)/bp1:RequestingBusinessActivity/@nameID"/>
                </xsl:attribute>
            </xsl:element>
            <xsl:element name="Performs" namespace="http://www.oasis-open.org/committes/ebBP">
                <xsl:attribute name="currentRoleRef">
                    <xsl:value-of select="./@toRoleIDREF"/>
                </xsl:attribute>
                <xsl:attribute name="respondingRoleRef">
                    <xsl:value-of select="key('bt',$ref)/bp1:RespondingBusinessActivity/@nameID"/>
                </xsl:attribute>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:Transition">
        <xsl:element name="BusinessDocument" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <!-- FromLink -->
            <!-- ToLink -->
        </xsl:element>
    </xsl:template>
    <!-- Conversion from 1.x versions will need editing and corrections -->
    <xsl:template match="bp1:Decision">
        <xsl:element name="Decision" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <!-- FromLink added in 2.0-->
            <!-- ToLink added in 2.0  -->
        </xsl:element>
    </xsl:template>
      <!-- Conversion from 1.x versions will likely need editing and corrections -->
    <xsl:template match="bp1:Fork">
        <xsl:element name="Fork" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <!-- FromLink -->
            <!-- ToLink -->
        </xsl:element>
    </xsl:template>
      <!-- Conversion from 1.x versions will likely need editing and corrections -->
    <xsl:template match="bp1:Join">
        <xsl:element name="Join" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <!-- FromLinks  added in 2.0-->
            <!-- ToLink added in 2.0 -->
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:Success">
        <xsl:element name="Success" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <!-- FromLink -->
            <xsl:element name="FromLink">
                <xsl:attribute name="conditionGuard">
                    <xsl:value-of select="./@conditionGuard"/>
                </xsl:attribute>
                <xsl:attribute name="fromBusinessStateRef">
                    <xsl:value-of select="./@fromBusinessState"/>
                </xsl:attribute>
                <xsl:apply-templates select="bp1:ConditionExpression"/>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:Failure">
        <xsl:element name="Failure" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="name">
                <xsl:value-of select="./@name"/>
            </xsl:attribute>
            <xsl:attribute name="nameID">
                <xsl:value-of select="./@nameID"/>
            </xsl:attribute>
            <xsl:apply-templates select="bp1:Documentation"/>
            <!-- FromLink  added in 2.0 -->
            <xsl:element name="FromLink">
                <xsl:attribute name="conditionGuard">
                    <xsl:value-of select="./@conditionGuard"/>
                </xsl:attribute>
                <xsl:attribute name="fromBusinessStateRef">
                    <xsl:value-of select="./@fromBusinessState"/>
                </xsl:attribute>
                <xsl:apply-templates select="bp1:ConditionExpression"/>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template match="bp1:ConditionExpression">
        <xsl:element name="ConditionExpression" namespace="http://www.oasis-open.org/committes/ebBP">
            <xsl:attribute name="expression">
                <xsl:value-of select="./@expression"/>
            </xsl:attribute>
            <xsl:attribute name="expressionLanguage">
                <xsl:value-of select="./@expressionLanguage"/>
            </xsl:attribute>
            <xsl:if test="@default">
                <xsl:attribute name="default">
                    <xsl:value-of select="@default"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="bp1:Documentation"/>
        </xsl:element>
    </xsl:template>
</xsl:stylesheet>
